

clear
set more off
set mem 100m
set matsize 500
#delimit;

cd "C:\Users\Elisa Cascardi\Desktop\Tribe or Nation\Replication";
cap log using tribe-or-nation_log2, replace text;


/* I - DATA CONSTRUCTION TANZANIA */;

/* Match VID, VID2 */;
/* NEED TO EDIT THIS FILE TO GIVE SUNGU A DIFFERENT NUMBER */;
insheet using school_list_may02.csv;
keep vid vid2 village division;
sort vid2;
drop if vid2==vid2[_n-1];
quietly summ;
sort vid;
save f0, replace;
clear;

/* WATER DATA */;
insheet using water-taxes_30may02.csv;
quietly summ; quietly desc;

/* THE KEY WATER VARIABLE IS THE NUMBER OF WELLS WITH "NORMAL" FLOW
	PER VILLAGE/SCHOOL COMMUNITY */;

gen flow_water = 0;
gen all_water = 0;

gen water1_ = real(water1);
replace water1_ = 2 if water1=="2/with pump";
drop water1;
quietly rename water1_ water1;

gen water2_ = real(water2);
replace water2_ = 3 if water2=="3,riverbed";
drop water2;
quietly rename water2_ water2;

local i=1;
while `i' <= 13 {;
	gen flow_`i' = 0;
	quietly replace flow_`i' = 1
		if (floww`i' == "1" | floww`i' == "1, 2" | floww`i'=="seasonal");
	quietly replace flow_water = flow_water + flow_`i';

	gen any_`i' = 0;
	quietly replace any_`i' = 1
		if (water`i'>0 & water`i'<4);
	quietly replace all_water = all_water + any_`i';

	local i = `i'+ 1;
};

gen flow_14 = 0;
replace flow_14 = 1 if (floww14==1);
gen flow_15 = 0;
replace flow_15 = 1 if (floww15==1);

quietly summ flow_* any_*;
quietly summ *_water;
quietly tab flow_water;
quietly tab all_water;
gen prop_water = flow_water / all_water;

keep vid flow_water prop_water all_water;
sort vid;
merge vid using f0;
tab _merge; drop _merge;
sort vid2;
save f_water, replace;
clear;


/* TAX DATA */;
insheet using water-taxes_30may02.csv;

/* THE KEY TAX VARIABLE IS THE TOTAL TAX COLLECTION PER VILLAGE */;
/* 	Assume that the tax is split evenly
	between the two categories in this one case */;

replace total2 = "1618500" if (vid==3132);
replace total3 = "1618500" if (vid==3132);

replace total6 = "" if vid==3152;
replace total7 = "" if vid==3161;

/* Tax category 8 is missing */;
/* Categories 2, 3, 6, 7 are strings, other are real */;
gen tax_1 = total1;
replace tax_1 = 0 if tax_1==.;

gen tax_4 = total4;
replace tax_4 = 0 if tax_4==.;

gen tax_5 = total5;
replace tax_5 = 0 if tax_5==.;


gen tax_2 = real(total2);
replace tax_2 = 0 if tax_2==.;

gen tax_3 = real(total3);
replace tax_3 = 0 if tax_3==.;

gen tax_6 = real(total6);
replace tax_6 = 0 if tax_6==.;

gen tax_7 = real(total7);
replace tax_7 = 0 if tax_7==.;

gen tot_tax = tax_1 + tax_2 + tax_3 + tax_4 + tax_5 + tax_6 + tax_7;

quietly summ *tax*;
quietly summ tot_tax;
quietly tab tot_tax;

keep vid tot_tax; 
sort vid;
merge vid using f0;
tab _merge; drop _merge;
sort vid2;
save f_tax, replace;
clear;

/* I cleaned the dataset school1_18may02.csv by hand, making all of the text field (that had a few
random comments in them) into numeric fields.  This file is then called school1B_18may02.csv.  I did the
same thing for school2_18may02.csv.  Now we merge them together and include them in the analysis.
*/;

/* For "s1oth", I have only included cash amounts; we still need to price the value of maize and
sorghum that was also grown by the school.  */;

insheet using school1B_18may02.csv;
save school1_may02, replace;

quietly rename s1name s_name; 
quietly rename s1boys s_boys;
quietly rename s1girls s_girls;
quietly rename s1total s_total;
quietly rename s1teach s_teach;
quietly rename s1actupe s_actupe;
quietly rename s1expupe s_expupe;
quietly rename s1fund s_fund;
quietly rename s1oth s_oth;
quietly rename s1desks s_desks;
quietly rename s1latrin s_latrin;
quietly rename s1south s_south;
quietly rename s1east s_east;
quietly rename s1feet s_feet;
quietly rename s1wp s_wp;
quietly rename s1end s_end;

local i=1;
while `i' <= 8 {;
	quietly rename s1struc`i' s_struc`i';
	quietly rename s1wall`i' s_wall`i';
	quietly rename s1roof`i' s_roof`i';
	quietly rename s1year`i' s_year`i';
	quietly rename s1no`i' s_no`i';
	local i = `i'+ 1;
};

save school1_may02, replace;
clear;

insheet using school2B_18may02.csv;
save school2_may02, replace;

quietly rename s2name s_name; 
quietly rename s2boys s_boys;
quietly rename s2girls s_girls;
quietly rename s2total s_total;
quietly rename s2teach s_teach;
quietly rename s2actupe s_actupe;
quietly rename s2expupe s_expupe;
quietly rename s2fund s_fund;
quietly rename s2oth s_oth;
quietly rename s2desks s_desks;
quietly rename s2latrin s_latrin;
quietly rename s2south s_south;
quietly rename s2east s_east;
quietly rename s2feet s_feet;
quietly rename s2wp s_wp;
quietly rename s2end s_end;

local i=1;
while `i' <= 8 {;
	quietly rename s2struc`i' s_struc`i';
	quietly rename s2wall`i' s_wall`i';
	quietly rename s2roof`i' s_roof`i';
	quietly rename s2year`i' s_year`i';
	quietly rename s2no`i' s_no`i';
	local i = `i'+ 1;
};

save school2_may02, replace;
append using school1_may02, force;

save vc_schools_sep02A, replace;
summ;

/* Now collapse the data by village ID */;
/* First match to VID2; 
There are some problems - some "villages" are really sub-villages:
set Sungu VID=9999 
Isengwa = 1011/1015
Witamhiya = 3133/3131
Mwashata = 2093/other
*/;
sort vid;
merge vid using f0;
tab _merge; 
drop if _merge==2;
drop _merge;
save vc_schools_sep02A, replace;


/* Export this data for Chip - NOT NOW */;
/*
rename s_name school_name;
rename s_latr latrines;
outsheet vid vid2 division village school_name latrines using latrines_05sep02.xls, replace;
clear;
*/;


/* Construct village-level variables */;
use vc_schools_sep02A;
collapse (sum) s_total s_boys s_girls s_teach s_actupe s_fund s_oth s_no* s_desks s_latrin,
	by(vid2);

/* Total number of classrooms */;
gen s_classr = s_no1;
quietly replace s_classr = s_classr + s_no2 if s_no2~=.;
quietly replace s_classr = s_classr + s_no3 if s_no3~=.;
quietly replace s_classr = s_classr + s_no4 if s_no4~=.;
quietly replace s_classr = s_classr + s_no5 if s_no5~=.;
quietly replace s_classr = s_classr + s_no6 if s_no6~=.;
quietly replace s_classr = s_classr + s_no7 if s_no7~=.;
quietly replace s_classr = s_classr + s_no8 if s_no8~=.;
drop s_no*;

/* Total amount of funding */;
gen s_schfunds = s_actupe + s_fund + s_oth;
drop s_actupe s_fund s_oth;

sort vid2;
save vc_schools_sep02, replace;
clear;

/* EXAMINE ONGOING PROJECTS, ROADS, AND COMMUNITY GROUPS */;
use vcproject_sep02;

/* NEED TO GET INCOME DIRECTLY FROM THE HH SURVEY DATA IN THE FUTURE */;

/* REPLACE ONE STRING WITH NUMERIC VALUES */;
rename cm_oth_price temp;
gen cm_oth_price = .;
replace cm_oth_price = 1000000 if temp=="1,000,000";
replace cm_oth_price = 1100000 if temp=="1,100,000";
drop temp;

/* Use "other" tribe data */;
/* Sukuma */;
replace trsukum = trsukum + troth1 if 
	(tr1des=="? baluli sukuma");
/* Nyiramba - COUNTING "MIXED" PEOPLE */;
replace trnyiram = trnyiram + troth1 if
	(tr1des=="mixed nyiramba/sukuma" | tr1des=="mixed sukuma/nyiramba"
	| tr1des=="nyisanzu" | tr1des=="nysanzu");
replace trnyiram = trnyiram + troth2 if
	(tr2des=="mwyisanzu" | tr2des=="nyisanzu");
replace trnyiram = trnyiram + troth3 if
	(tr3des=="nysansu");
/* Taturu */;
replace trtatur = trtatur + troth1 if
	(tr1des=="mangati" | tr1des=="taturu/mangati");
/* Nyaturu */;
gen trnyaturu = 0 if trsukum~=.;
replace trnyaturu = trnyaturu + troth1 if
	(tr1des=="nyaturu");
replace trnyaturu = trnyaturu + troth2 if
	(tr2des=="nyaturu");
/* Shashi */;
gen trshashi = 0 if trsukum~=.;
replace trshashi = trshashi + troth1 if
	(tr1des=="shashi");
replace trshashi = trshashi + troth2 if
	(tr2des=="shashi");
replace trshashi = trshashi + troth3 if
	(tr3des=="shashi");
/* Luo */;
gen trluo = 0 if trsukum~=.;
replace trluo = trluo + troth2 if
	(tr2des=="jaruo");
replace trluo = trluo + troth3 if
	(tr3des=="jaruo" | tr3des=="luo");
/* Nyamwezi */;
gen trnyamwezi = 0 if trsukum~=.;
replace trnyamwezi = trnyamwezi + troth1 if
	(tr1des=="myammwezi");
/* Hadzabe */;
gen trhadzabe = 0 if trsukum~=.;
replace trhadzabe = trhadzabe + troth3 if
	(tr3des=="wahazabel");
/* Jita */;
gen trjita = 0 if trsukum~=.;
replace trjita = trjita + troth2 if
	(tr2des=="jita");
/* Kuria */;
gen trkuria = 0 if trsukum~=.;
replace trkuria = trkuria + troth2 if
	(tr2des=="kurya");
/* Masaai */;
gen trmasaai = 0 if trsukum~=.;
replace trmasaai = trmasaai + troth3 if
	(tr3des=="masaii");
/* Gogo */;
gen trgogo = 0 if trsukum~=.;
replace trgogo = trgogo + troth1 if
	(tr1des=="masaii");
/* Hehe */;
gen trhehe = 0 if trsukum~=.;
replace trhehe = trhehe + troth2 if
	(tr2des=="hehe");
/* Pare */;
gen trpare = 0 if trsukum~=.;
replace trpare = trpare + troth1 if
	(tr1des=="parc");
/* Bulu */;
gen trbulu = 0 if trsukum~=.;
replace trbulu = trbulu + troth1 if
	(tr1des=="bulu");
/* Kizu */;
gen trkizu = 0 if trsukum~=.;
replace trkizu = trkizu + troth1 if
	(tr1des=="kizu");
/* Muha */;
gen trmuha = 0 if trsukum~=.;
replace trmuha = trmuha + troth1 if
	(tr1des=="muha");
/* Mukalawa */;
gen trmukalawa = 0 if trsukum~=.;
replace trmukalawa = trmukalawa + troth1 if
	(tr1des=="mukalawa");
/* Uganda */;
gen truganda = 0 if trsukum~=.;
replace truganda = truganda + troth2 if
	(tr2des=="uganda");
/* Coast */;
gen trcoast = 0 if trsukum~=.;
replace trcoast = trcoast + troth2 if
	(tr2des=="from zanzibai" | tr2des=="mwarabu");
/* DK */;
gen trdk = 0 if trsukum~=.;
replace trdk = trdk + troth1 if
	(tr1des=="0" | tr1des=="DK");
replace trdk = trdk + troth2 if
	(tr2des=="DK");
replace trdk = trdk + troth3 if
	(tr3des=="DK");

list village if (vid2==17 | vid2==41 | vid2==42 | vid2==71 | vid2==72);

collapse 	wardno divno
		femgrp ythgrp wtrgrp othgrp
		force conflict
		roads
		kaya pop
		trsukum trnyiram trtatur troth1 troth2 troth3 trnyaturu-trdk
		ccm00 udp00 cuf00 non00 oth00
		ycapusd
		(sum) cm_*,
		by(vid2);


gen temp_total2 = trsukum + trnyiram + trtatur
	+ troth1 + troth2 + troth3 - trdk;
gen temp_total = trsukum + trnyiram + trtatur +
	trnyaturu + trshashi + trluo + trnyamwezi + trhadzabe + 
	trjita + trkuria + trmasaai + trgogo + trhehe + trpare +
	trbulu + trkizu + trmuha + trmukalawa + truganda + trcoast;

summ temp_total* if temp_total>0;

gen pr_sukuma = trsukum/temp_total;
gen pr_nyiramba = trnyiram/temp_total;
gen pr_tatur = trtatur/temp_total;
gen pr_nyaturu = trnyaturu/temp_total;
gen pr_shashi = trshashi/temp_total;
gen pr_luo = trluo/temp_total;
gen pr_nyamwezi = trnyamwezi/temp_total;
gen pr_hadzabe = trhadzabe/temp_total;
gen pr_jita = trjita/temp_total;
gen pr_kuria = trkuria/temp_total;
gen pr_masaai = trmasaai/temp_total;
gen pr_gogo = trgogo/temp_total;
gen pr_hehe = trhehe/temp_total;
gen pr_pare = trpare/temp_total;
gen pr_bulu = trbulu/temp_total;
gen pr_kizu = trkizu/temp_total;
gen pr_muha = trmuha/temp_total;
gen pr_mukalawa = trmukalawa/temp_total;
gen pr_uganda = truganda/temp_total;
gen pr_coast = trcoast/temp_total;

/* There is a strange outlier, vid2==17, which is in Kisesa and almost
	certainly is 100 percent Sukuma.  The proportions of different ethnic
	groups from the Tax Register are "missing", even though is most likely a typo
Replace with pr_sukuma=1,
	From the HH surveys, this is a 100 percent Sukuma village */;
replace pr_sukuma=1 if vid2==17;

/* ELF from the tax register == elfr */;
gen elfr = 1 - pr_sukuma^2 - pr_nyiramba^2 - pr_tatur^2
	- pr_nyaturu^2 - pr_shashi^2 - pr_luo^2 - pr_nyamwezi^2
	- pr_hadzabe^2 - pr_jita^2 - pr_kuria^2 - pr_masaai^2
	- pr_gogo^2 - pr_hehe^2 - pr_pare^2 - pr_bulu^2
	- pr_kizu^2 - pr_muha^2 - pr_mukalawa^2 - pr_uganda^2 - pr_coast^2;

summ elfr, det;
list vid* elfr pr* if elfr>=0.5 & elfr~=.;

gen large_gp = max(pr_sukuma, pr_nyiramba, pr_tatur, pr_nyaturu, pr_shashi,
	pr_luo, pr_nyamwezi, pr_hadzabe, pr_jita, pr_kuria, pr_masaai,
	pr_gogo, pr_hehe, pr_pare, pr_bulu, pr_kizu, pr_muha, pr_mukalawa,
	pr_uganda, pr_coast);
summ large_gp;

/* Majority ethnic group in the district; replace with Luhyas in Busia */;
gen maj_gp = pr_sukuma;


/* Total number of community groups */;
/* Do VC, HH surveys correspond? BASICALLY, YES */;
gen totgrp = femgrp + ythgrp + wtrgrp + othgrp;

/* Create number of completed projects per year, 1997-2002, six years */;
gen cm_num_peryr = cm_num/6;

/* Proportion of parties in VC */;
replace temp_total = ccm00 + udp00 + cuf00 + non00 + oth00;
gen pr_ccm00 = ccm00/temp_total;
gen pr_udp00 = udp00/temp_total;
gen pr_cuf00 = cuf00/temp_total;
gen pr_non00 = non00/temp_total;
save f1, replace;

merge vid2 using vc_schools_sep02;
tab _merge; drop _merge;
summ;


/* Include division dummies sometimes */;
tab divno, gen(Idiv);

sort vid2;
merge vid2 using f_tax;
tab _merge; drop _merge;

sort vid2;
merge vid2 using f_water;
tab _merge; drop _merge;

save f1, replace;
clear;


/* 2001 HH survey data */;
use hh01_sep02;

/* CONSUMPTION DATA */;
desc nonyr15-nonyr18;
summ nonyr15-nonyr18;

/* Missings are zeros in the consumption survey */;
gen hh_charity = nonyr15;
replace hh_charity = . if cfood1==.;

gen hh_taxes = nonyr16;
replace hh_taxes = . if cfood1==.;

gen hh_school = nonyr17;
replace hh_school = . if cfood1==.;

gen hh_rosca = nonyr18;
replace hh_rosca = . if cfood1==.;

gen hh_contrib = hh_taxes + hh_school;

summ hh_*, det;

keep villno tribe relig formal educ cotton roof* cow member ycapus2 hh_*;

/* Indicator for Sukuma tribe */;
gen hh_sukuma = .;
replace hh_sukuma = 1 if tribe==1;
replace hh_sukuma = 0 if tribe>1 & tribe<9;

gen norelig = .;
replace norelig = 1 if relig==6;
replace norelig = 0 if relig~=6 & relig~=.;
gen catholic = .;
replace catholic = 1 if relig==1;
replace catholic = 0 if relig~=1 & relig~=.;

/* formal sector, salaried employment */;
gen formal_work = formal;

/* years of education */;
rename educ educat;

/* grows cash crop */;
gen cashcrop = cotton;

/* has iron roofing somewhere in compound */;
gen ironroof = 0;
replace ironroof = 1 if
	(roof1==1 | roof2==2 | roof3==1 | roof4==1 | roof5==1 | 
	roof6==1 | roof7==2 | roof8==1 | roof9==1 | roof10==1);

/* owns cattle */;
gen owncows = 0;
replace owncows=1 if cow>0 & cow~=.;

/* member of community group */;
gen commgrp = member;


/* GENERATE GINI COEFFICIENT */;
/* THIS MEASURE IS LIKELY TO BE VERY NOISY GIVEN THE SMALL NUMBER OF OBSERVATIONS
	PER VILLAGE, THUS LEADING TO ATTENUATION IN THE COEFFICIENT ESTIMATE ON
	THE GINI COEFFICIENT IN ANY REGRESSION */;

sort villno ycapus2;

egen y_vill = mean(ycapus2), by(villno);
egen ny_vill = count(ycapus2), by(villno);
egen rank_vill = rank(ycapus2), field by(villno);

gen temp = rank_vill*ycapus2;
egen sum_vill = sum(temp), by(villno);
drop temp;

by villno: gen gini_vill = (ny_vill+1)/(ny_vill-1) - 2/(ny_vill*(ny_vill-1)*y_vill)*sum_vill;
drop rank_vill sum_vill;

collapse hh_* norelig catholic formal_work educat cashcrop ironroof owncows commgrp
	ny_vill y_vill gini_vill, by(villno);

summ;
sort villno;
quietly rename villno vid;
merge vid using f0;
tab _merge; drop _merge;
sort vid2;
save f2, replace;
clear;

use f1;
sort vid2;
merge vid2 using f2;
tab _merge; drop _merge;
save f1, replace;
clear;


/* Now incorporate village meeting attendance data */;
use vc-attendance_07aug02;
gen vmtg01 = m1att + m2att + m3att + m4att + m5att;
summ;
keep vid2 vmtg01;
sort vid2;
save f2, replace;
clear;

use f1;
sort vid2;
merge vid2 using f2;
tab _merge; drop _merge;
save f1, replace;
clear;


/* NOW INCORPORATE 2002 HH DATA */;
/*cd ..;
cd data_2002;*/
use meatu02;
keep vid vcmeeting_8_1 pra_8_2 *grp*
	unity_8_19 participat_8_20 cooperat_8_21 
	rank* trust*;

/* construct variables */;
gen vc2002 = .;
replace vc2002 = 1 if vcmeeting_8_1==1;
replace vc2002 = 0 if vcmeeting_8_1==2;

gen pra2002 = .;
replace pra2002 = 1 if pra_8_2==1;
replace pra2002 = 0 if pra_8_2==2;
/*
foreach var in
	f_womengrp f_agrigrp f_youthgrp f_watrgrp
	f_creditgrp f_religgrp f_politgrp f_othrgrp
	m_agrigrp m_youthgrp m_watrgrp
	m_creditgrp m_religgrp m_politgrp m_othrgrp
{;
replace `var' = . if (`var'~=1 & `var'~=2);
replace `var' = 0 if `var'==2;
};
*/
gen f_grptot = 	f_womengrp + f_agrigrp + f_youthgrp + f_watrgrp
	+ f_creditgrp + f_religgrp + f_politgrp + f_othrgrp;
gen m_grptot = 	m_agrigrp + m_youthgrp + m_watrgrp
	+ m_creditgrp + m_religgrp + m_politgrp + m_othrgrp;
gen grptot = f_grptot + m_grptot;


gen unity2002 = .;
replace unity2002 = 1 if (unity_8_19==1 | unity_8_19==2);
replace unity2002 = 0 if (unity_8_19==3 | unity_8_19==4 | unity_8_19==5);

gen part2002 = .;
replace part2002 = 1 if (participat_8_20==1 | participat_8_20==2);
replace part2002 = 0 if (participat_8_20==3 | participat_8_20==4 | participat_8_20==5);

gen coop2002 = .;
replace coop2002 = 1 if (cooperat_8_21==1 | cooperat_8_21==2);
replace coop2002 = 0 if (cooperat_8_21==3 | cooperat_8_21==4 | cooperat_8_21==5);


/* INDICATOR, NATION RANKED OVER TRIBE */;
gen rank_nation = 2 - rankb_8_22b;

/* INDICATOR, TRUST OTHER TRIBES */;
gen trust_trb = 2 - trustothr_8_25 if (trustothr_8_25==1 | trustothr_8_25==2);

collapse vc2002 pra2002
	f_grptot m_grptot grptot
	unity2002 part2002 coop2002
	rank_nation trust_trb, by(vid);

sort vid;
/*cd ..;
cd data_2001; */
merge vid using f0;
tab _merge; drop _merge;
sort vid2;
save f2, replace;
clear;

use f1;
sort vid2;
merge vid2 using f2;
tab _merge; drop _merge;
save f1, replace;
clear;


/* Now incorporate total funding data */;
use vcproject-cost_sep02;
keep vid2 yrexp_cm_tot yrexp_cm_sch yrexp_cm_well yrexp_cm_health;
collapse (sum) yrexp_cm_tot yrexp_cm_sch yrexp_cm_well yrexp_cm_health, by(vid2);

sort vid2;
save f2, replace;
clear;

use f1;
sort vid2;
merge vid2 using f2;
tab _merge; drop _merge;
save f1, replace;

foreach var in
	flow_water all_water
	tot_tax
	yrexp_cm_tot yrexp_cm_sch yrexp_cm_well yrexp_cm_health
	totgrp femgrp ythgrp wtrgrp othgrp
	vmtg01
	{;
	quietly gen `var'_perkaya = `var'/kaya;
	quietly gen `var'_perpup = `var'/s_total;
	};

foreach var in
	teach desks latrin classr schfunds
	{;
	quietly gen `var'_perpup = s_`var'/s_total;
	};

regress kaya s_total;
regress kaya s_total if vid2~=49;

/* KAYA and S_TOTAL are *very* highly correlated except for VID2=49, Irambandogo. */;
drop if vid2 == 49;

/* Correlate proportion Sukuma from VC and HH surveys - over 0.7 */;
correlate pr_sukuma hh_sukuma;
graph7 hh_sukuma pr_sukuma, s([vid2]) saving(corr_sukuma, replace);


/* ROAD QUALITY GOES FROM 1 (BEST) TO 4 (WORST).  TRANSFORM IT SO
	THAT THE MEASURE IS INCREASING IN QUALITY */;
replace roads = 5 - roads;


/* CHANGE TO HH_SUKUMA? */;


/* CREATE GROUPS OF VARIABLES */;
gl control1 = "educat formal_work ironroof cashcrop owncows catholic";
gl control2 = "y_vill gini_vill pr_sukuma kaya norelig veg_avgh";
gl divisions = "Idiv1 Idiv2 funyula butula nambale matayos budalang amukura";


/* Control for propensity for drought, especially when water wells is the outcome, 
	as a control for aridity??? ONLY HAVE THIS DATA FOR TZ, THOUGH */;


/* NORMALIZE ALL OUTCOMES */;
foreach var in
/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	yrexp_cm_sch_perpup
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water

/* OTHER OUTCOMES */
	/* Value of projects */
	yrexp_cm_tot_perkaya 
	yrexp_cm_well_perkaya 
	yrexp_cm_health_perkaya 

	/* Total number of local projects per year */
	cm_num_peryr

	/* Road Quality */
	roads

	/* Wells */
	flow_water_perkaya all_water_perkaya

	/* Tax collection */
	tot_tax_perkaya

	/* HH01 data on local contributions */
	hh_taxes hh_school

	/* Group outcomes */
	totgrp_perkaya femgrp_perkaya ythgrp_perkaya wtrgrp_perkaya /* VC01 */
	commgrp /* HH01 */

	/* Village meeting attendance */
	vmtg01_perkaya

/* CONTROLS / CHARACTERISTICS */
	teach_perpup pr_ccm00

	{;
	quietly egen `var'_std = std(`var');
	};

/* CREATE AN "OVERALL" COLLECTIVE ACTION OUTCOME, FOR COMMON MEASURES */;
gen collact = 
	yrexp_cm_sch_perpup_std
	+ desks_perpup_std + latrin_perpup_std + classr_perpup_std
	+ prop_water_std;
egen collact_std = std(collact);
drop collact;
save f_villages, replace;
clear;

/* Merge in the satellite vegetation data */;
use f_sat-data;
collapse veg_avgh, by(vid);
sort vid;
save f_temp, replace;
clear;

use f_villages;
sort vid;
merge vid using f_temp;
tab _merge; drop _merge;
save f_villages, replace;
clear;


/* Create a map of ethnic diversity and village location */;
insheet using meatu-gps_sep02.csv;
gen south_tz = degrees_south + (minutes_south)/60;
gen north_tz = -1*south_tz;
gen east_tz  = degrees_east  + (minutes_east)/60;
keep vid  north_tz east_tz;
sort vid;
save f_gps, replace;
clear;

use f_villages;
sort vid;
merge vid using f_gps;
tab _merge;
drop _merge;
sort vid;
save f_villages, replace;

gen elfr_temp = int(100*elfr);
replace elfr_temp = elfr_temp/100;
label var north_tz "Degrees North";
label var east_tz "Degrees East";
graph7 north_tz east_tz, s([elfr_temp])
	xlabel(34.0 34.2 34.4 34.6 34.8) ylabel(-4.0 -3.8 -3.6 -3.4 -3.2 -3.0) saving(mapA-tz, replace);
graph7 north_tz east_tz, s([vid2])
	xlabel(34.0 34.2 34.4 34.6 34.8) ylabel(-4.0 -3.8 -3.6 -3.4 -3.2 -3.0) saving(mapB-tz, replace);
drop elfr_temp;


/* WHAT ARE THE TZ VILLAGES WITH MISSING DATA LIKE? (IN TERMS OF DIVERSITY) */;
drop if vid2==.;

list vid2 if elfr==.;

gen missing = (vid2==25 | vid2==27 | vid2==45
	| vid2==49 | vid2==52 | vid2==55 | vid2==72);

bys missing: summ elfr;
ttest elfr, by(missing);



/* WARD AVERAGES, WEIGHTED BY KAYA */;
drop village division;
collapse divno-collact_std
	(sum) tot_sukum=trsukum tot_nyiram=trnyiram tot_tatur=trtatur
		tot_oth1=troth1 tot_oth2=troth2 tot_oth3=troth3 [aw=kaya], by (wardno);

replace temp_total = tot_sukum + tot_nyiram + tot_tatur + tot_oth1 + tot_oth2 + tot_oth3;
gen elfr_ward = 1;
foreach var in
	sukum nyiram tatur oth1 oth2 oth3
	{;
	quietly gen prop_`var' = tot_`var'/temp_total;
	quietly replace elfr_ward = elfr_ward - prop_`var'^2;
	};
summ elfr_ward, det;

sort wardno;
save f_ward, replace;
clear;


/* II - DATA CONSTRUCTION KENYA */;

/* WATER DIRECTORY */;
/*cd ..;
cd ..;
cd Water; */
use well-ethnicII_jun02.dta;
/*cd ..;
cd Tanzania\data_2001;*/

keep schid well_5km works2_5km no_brms_5km;
rename schid schoolid;
sort schoolid;
save f1, replace;
clear;

/*cd ..;
cd ..;
cd Tribes\UCB_Tribes;*/
use gps-ethnic_jun02.dta;
/*cd ..;
cd ..;
cd Tanzania\data_2001;
*/
keep schid sch_5km tot_5km;
drop if schid>199;
rename schid schoolid;
sort schoolid;
save f2, replace;
clear;

/*cd ..;
cd ..;
cd Tribes\UCB_Tribes; */
use f_kenya.dta;
/*cd ..;
cd ..;
cd Tanzania\data_2001;*/

drop if schoolid>199;
/* Keep consistent sample with first paper */;
drop if sc99_psanct==.;
sort schoolid;
merge schoolid using f1;
tab _merge; drop _merge;

sort schoolid;
merge schoolid using f2;
tab _merge; drop _merge;

rename funds_96 yrexp_cm_sch_perpup;
rename desk2pup desks_perpup;
rename plat2pup latrin_perpup;
rename room2pup classr_perpup;
gen teach_perpup = 1/pup2tch;

rename well_5km all_water;
rename works2_5km flow_water;
gen prop_water = flow_water/all_water;

/* NORMALIZE */;
foreach var in
	yrexp_cm_sch_perpup
	teach_perpup
	desks_perpup
	latrin_perpup
	classr_perpup
	prop_water
	flow_water
	all_water
	{;
	quietly egen `var'_std = std(`var');
	};

/* CREATE AN "OVERALL" COLLECTIVE ACTION OUTCOME, FOR COMMON MEASURES */;
gen collact = 
	yrexp_cm_sch_perpup_std
	+ desks_perpup_std + latrin_perpup_std + classr_perpup_std
	+ prop_water_std;
egen collact_std = std(collact);
drop collact;


/* ANALYSIS AT THE VILLAGE/SCHOOL LEVEL */;

/* SES, ETHNIC CONTROLS */;
rename cattle owncows;
rename fyrsed educat;
rename fformwk formal_work;
rename elfA_5km elfr;
gen kenya = 1;

/* Majority ethnic group in the district */;
gen maj_gp = luhya;

rename zoneid wardno;
replace wardno = 100 + wardno;
rename schoolid vid2;
replace vid2 = vid2+100;
sort vid2;
save f_schools, replace;
clear;


use f_villages;
sort vid2;
merge vid2 using f_schools;
tab _merge; drop _merge;
tab vid2;

replace kenya = 0 if kenya==.;
summ kenya;


/* FUNDRAISING PER PUPIL AND PER HOUSEHOLD, PER YEAR, IN 2002 USD */;
/*
The KSH:USD exchange rate in June 1995 was 53.2:1, according to:
http://www.oanda.com/convert/classic
*/;

/* 
The TZSH:USD exchange rate in June 2001 was 886:1, according to:
http://www.oanda.com/convert/classic
The TZSH:USD exchange rate in August 2002 was 984:1, according to:
http://www.oanda.com/convert/classic

The 2002 figure is the key rate for us, since the project price figures we
obtained from DRDP are for 2002.  The 2001 HH and VC data is converted
at the 2001 rate, above.
*/;

/* Inflation in the US between 1995 and 2002 was 1/0.845, and between 2001 and 2002 was 1/0.982
according the Census Bureau and the Bureau of Labor Statistics:
http://www.orst.edu/dept/pol_sci/fac/sahr/sahr.htm
*/;

gen sch_funds_usd = yrexp_cm_sch_perpup/53.2/0.845 if kenya==1;
/* For years 1997 to 2002 in Tanzania - divide by six years */;
replace sch_funds_usd = yrexp_cm_sch_perpup/984/6 if kenya==0;
gen tot_funds_usd = yrexp_cm_tot_perkaya/984/6 if kenya==0;
gen well_funds_usd = yrexp_cm_well_perkaya/984/6 if kenya==0;
gen health_funds_usd = yrexp_cm_health_perkaya/984/6 if kenya==0;

gen tot_tax_usd = tot_tax_perkaya/886/0.982 if kenya==0;
gen hh_taxes_usd = hh_taxes/886/0.982 if kenya==0;
gen hh_school_usd = hh_school/886/0.982 if kenya==0;

/* COMBINE SEVERAL OF THESE MEASURES */;
gen hh_taxes_school_usd = hh_taxes_usd + hh_school_usd;
gen health_well_funds_usd = well_funds_usd + health_funds_usd;


/* Keep consistent sample */;
drop if (sch_funds_usd==. | elfr==. | prop_water==. | catholic==. | formal_work==.);
save f0, replace;


/* INCLUDE DIVISION/REGION DUMMIES FOR BOTH COUNTRIES */;
/* Which divisions do these actually correspond to? */;
replace Idiv1 = 0 if Idiv1==.;
replace Idiv2 = 0 if Idiv2==.;

foreach var in
	funyula butula nambale matayos budalang amukura
	{;
	replace `var' = 0 if `var'==.;
	};

/* Create variable with common name, largest ethnic group in the community */;
replace large_gp = lgrp2_ALL if kenya==1;


/* Generate map with local ethnic diversity for Kenya */;
gen elfr_temp = int(100*elfr) if kenya==1;
replace elfr_temp = elfr_temp/100;
rename north north_k;
rename east east_k;
label var north_k "Degrees North";
label var east_k "Degrees East";
graph7 north_k east_k, s([elfr_temp])
	xlabel (34 34.2 34.4 34.6) ylabel(0 0.2 0.4 0.6 0.8) saving(map-k, replace);


/* GENERATE KENYA*ELF, TZ*ELF INTERACTION TERMS */;
gen kenya_elfr = kenya*elfr;
gen kenya_large = kenya*large_gp;

gen tz = 1-kenya;
gen tz_elfr = tz*elfr;
gen tz_large = tz*large_gp;


/* CREATE X*ELF, X*KENYA, X*TZ TERMS */;
foreach var in
educat formal_work ironroof cashcrop owncows catholic
{;
gen ex_`var' = elfr*`var';
gen kx_`var' = kenya*`var';
gen tzx_`var' = (1-kenya)*`var';
};
gl ex = "ex_educat ex_formal_work ex_ironroof ex_cashcrop ex_owncows ex_catholic";
gl kx = "kx_educat kx_formal_work kx_ironroof kx_cashcrop kx_owncows kx_catholic";
gl tzx = "tzx_educat tzx_formal_work tzx_ironroof tzx_cashcrop tzx_owncows tzx_catholic";

sort kenya;
save f0, replace;


/* III - DATA ANALYSIS */;

/* TABLE 1: Summary Statistics */;
summ 
/* COMMON OUTCOMES WITH KENYA */
elfr kenya $control1 $divisions
	/* School Outcomes */
	sch_funds_usd
	teach_perpup
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	flow_water prop_water all_water;

by kenya:
summ 	elfr kenya $control1 $divisions
/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup
	teach_perpup

	/* Wells */
	prop_water

/* TANZANIA ONLY DATA */
	$control2

	/* Value of projects */
	yrexp_cm_tot_perkaya tot_funds_usd 
	yrexp_cm_well_perkaya well_funds_usd
	yrexp_cm_health_perkaya health_funds_usd 
	health_well_funds_usd

	/* Number of projects */
	cm_num_peryr cm_num cm_sch

	/* Road Quality */
	roads

	/* Wells */
	flow_water_perkaya all_water_perkaya

	/* Tax collection */
	tot_tax_perkaya tot_tax_usd

	/* HH01 data on local contributions */
	hh_taxes hh_taxes_usd
	hh_school hh_school_usd
	hh_taxes_school_usd

	/* Group outcomes */
	totgrp_perkaya femgrp_perkaya ythgrp_perkaya wtrgrp_perkaya /* VC01 */
	commgrp /* HH01 */

	/* Village meeting attendance */
/* CLEANED UP NUMBER OF KAYAS IN VILLAGE VID2==12, it is 371 */
	vmtg01_perkaya

	/* VC politics */
	pr_ccm00

/* 2002 HH DATA */
	vc2002 pra2002
	f_grptot m_grptot grptot
	unity2002 part2002 coop2002
	rank_nation trust_trb;

summ kaya, det;

summ veg_avgh, det;
regress elfr veg_avgh, robust cluster(vid);


/* EVENTUALLY, RE-DO ALL RESULTS DROPPING ONE VILLAGE AT A TIME,
	TO SHOW THAT THE RESULTS ARE NOT ROBUST TO ANY ONE OUTLIER */;

/* FIGURE 1: MAP OF EAST AFRICA */;

/* FIGURE 2: ETHNIC DIVERSITY KERNEL DENSITY */;

kdensity elfr if kenya==1, title(School Diversity Kenya)
	saving(elf_K, replace) gen(xa elf_K);
display r(width);
kdensity elfr if kenya==0, title(Village Diversity Tanzania)
	saving(elf_TZ, replace) gen(xb elf_TZ);
display r(width);

label var xa "ELF";
label var elf_K "Community Diversity Kenya";
label var elf_TZ "Village Diversity Tanzania";
graph7 elf_K elf_TZ xa, s(ii) c(ll[-])
	xlabel (0, 0.2, 0.4, 0.6) ylabel saving(elf_KTZ_FIG2, replace);
drop xa xb;


/* APPENDIX */;
/* HOW SIMILAR ARE DIVERSE AND HOMOGENEOUS AREAS? */;
foreach var in
	educat formal_work ironroof cashcrop owncows catholic
	teach_perpup
	y_vill gini_vill pr_sukuma kaya force norelig pr_ccm00
	{;
	by kenya: summ `var';
	by kenya: regress `var' elfr, robust cluster(wardno);
	by kenya: correlate `var' elfr;
	regress `var' kenya elfr kenya_elfr, robust cluster(wardno);
	/* regress `var' kenya elfr kenya_elfr $divisions, robust cluster(wardno); */;
	};


/* TABLE 2: ETHNIC DIVERSITY EFFECTS, COMMON OUTCOMES */;
/* TABLE 3: ETHNIC DIVERSITY EFFECTS, LOCAL PUBLIC FINANCE AND COLLECTIVE ACTION */;
/* TABLE 4: ETHNIC DIVERSITY EFFECTS, LOCAL COMMUNITY GROUP ACTIVITY */;

foreach var in
/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

/* TANZANIA ONLY DATA */
	/* Value of projects */
	/* yrexp_cm_tot_perkaya */ tot_funds_usd 
	/* yrexp_cm_well_perkaya well_funds_usd */
	/* yrexp_cm_health_perkaya health_funds_usd */
	health_well_funds_usd

	/* Number of projects */
	cm_num_peryr

	/* Road Quality */
	roads

	/* Wells */
	flow_water_perkaya /* all_water_perkaya */

	/* Tax collection */
	/* tot_tax_perkaya */ tot_tax_usd

	/* HH01 data on local contributions */
	/* hh_taxes hh_taxes_usd */
	/* hh_school hh_school_usd */
	hh_taxes_school_usd

	/* Group outcomes */
	totgrp_perkaya femgrp_perkaya ythgrp_perkaya wtrgrp_perkaya /* VC01 */
	commgrp /* HH01 */

	/* Village meeting attendance */
	vmtg01_perkaya

/* 2002 HH DATA */
	vc2002 pra2002
	/* f_grptot m_grptot grptot */
	unity2002 part2002 coop2002
	rank_nation trust_trb
	
{;
	graph7 `var' elfr if kenya==1, xlabel saving(`var'_1K, replace);
	graph7 `var' elfr if kenya==0, xlabel saving(`var'_1TZ, replace);

	regress `var' kenya elfr kenya_elfr, robust cluster(wardno);
	regress `var' kenya elfr kenya_elfr $control1, robust cluster(wardno);
	regress `var' tz elfr tz_elfr $control1, robust cluster(wardno);

	/* KEY REGRESSIONS */;
	regress `var' kenya elfr kenya_elfr $control1 $kx, robust cluster(wardno);
	regress `var' tz elfr tz_elfr $control1 $tzx, robust cluster(wardno);
	regress `var' kenya elfr kenya_elfr $control1 $ex, robust cluster(wardno);
	regress `var' kenya elfr kenya_elfr $control1 $kx $ex, robust cluster(wardno);

	regress `var' kenya large_gp kenya_large $control1, robust cluster(wardno);
	regress `var' kenya elfr kenya_elfr $control1 $divisions, robust cluster(wardno);
	regress `var' kenya elfr kenya_elfr $control1 $control2, robust cluster(wardno);
	};

/* FIGURES 2, 3: SCHOOL FUNDING OUTCOMES (USD) */;
regress sch_funds_usd elfr if kenya==1;
gen k_funds = sch_funds_usd if kenya==1;
predict k_funds_hat;

regress sch_funds_usd elfr if kenya==0;
gen tz_funds = sch_funds_usd if kenya==0;
predict tz_funds_hat;

label var elfr "Local Ethnic diversity (ELF)";
label var k_funds "School Funding Kenya (USD)";
label var tz_funds "School Funding Tanzania (USD)";
graph7 k_funds tz_funds k_funds_hat tz_funds_hat elfr,
	s(OTii) c(..ll[.]) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k-tz_school-figure, replace); 

label var elfr "(a) Local Ethnic diversity (ELF)";
graph7 k_funds k_funds_hat elfr,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k_school-figure2, replace); 

label var elfr "(c) Local Ethnic diversity (ELF)";
graph7 tz_funds tz_funds_hat elfr,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(tz_school-figure2, replace); 
drop k_funds* tz_funds*;


/* DESKS */;
regress desks_perpup elfr if kenya==1;
gen k_desks = desks_perpup if kenya==1;
predict k_desks_hat;

regress desks_perpup elfr if kenya==0;
gen tz_desks = desks_perpup if kenya==0;
predict tz_desks_hat;

label var elfr "Local Ethnic diversity (ELF)";
label var k_desks "Desks per pupil Kenya";
label var tz_desks "Desks per pupil Tanzania";
graph7 k_desks tz_desks k_desks_hat tz_desks_hat elfr,
	s(OTii) c(..ll[.]) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k-tz_desks-figure, replace); 

label var elfr "(b) Local Ethnic diversity (ELF)";
graph7 k_desks k_desks_hat elfr,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k_desks-figure2, replace); 

label var elfr "(d) Local Ethnic diversity (ELF)";
graph7 tz_desks tz_desks_hat elfr,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(tz_desks-figure2, replace); 
drop k_desks* tz_desks*;

graph7 using k_school-figure2 k_desks-figure2 tz_school-figure2 tz_desks-figure2, saving(figure2, replace);


/* SEEMINGLY UNRELATED REGRESSION (SUR). WHEN ALL THE X VARIABLES ARE IDENTICAL,
	THE COEFFICIENT ESTIMATES ARE THE SAME AS OLS, BUT THIS METHOD ALLOWS US TO PERFORM 
	JOINT TESTS ON THE SIGNIFICANCE OF A PARTICULAR VARIABLE, HERE ELFR */;
/* SUR */;

/* TEST DIFFERENCE BETWEEN KENYA, TZ */;
sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= elfr kenya kenya_elfr),
	small dfk corr;
test elfr;
test kenya_elfr;

sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= elfr kenya kenya_elfr $control1),
	small dfk corr;
test elfr;
test kenya_elfr;

sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= elfr tz tz_elfr $control1),
	small dfk corr;
test elfr;
test tz_elfr;

/* KEY REGRESSION */;
sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= elfr kenya kenya_elfr $control1 $kx),
	small dfk corr;
test elfr;
test kenya_elfr;
test kenya;
test educat;
test formal_work;
test ironroof;
test cashcrop;
test owncows;
test catholic;

sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= elfr tz tz_elfr $control1 $tzx),
	small dfk corr;
test elfr;
test tz_elfr;
test tz;

sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= elfr kenya kenya_elfr $control1 $ex),
	small dfk corr;
test elfr;
test kenya_elfr;
test kenya;

sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= elfr kenya kenya_elfr $control1 $kx $ex),
	small dfk corr;
test elfr;
test kenya_elfr;
test kenya;

sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= large_gp kenya kenya_large $control1),
	small dfk corr;
test large_gp;
test kenya_large;

sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= elfr kenya kenya_elfr $control1 $divisions),
	small dfk corr;
test elfr;
test kenya_elfr;

/* TEST OVERALL PF EFFECT FOR TZ */;
sureg (/* ALL TZ OUTCOMES */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

/* TANZANIA ONLY DATA */
	/* Value of projects */
	/* yrexp_cm_tot_perkaya */ tot_funds_usd 
	/* yrexp_cm_well_perkaya well_funds_usd */
	/* yrexp_cm_health_perkaya health_funds_usd */
	health_well_funds_usd

	/* Number of projects */
	cm_num_peryr

	/* Road Quality */
	roads

	/* Wells */
	flow_water_perkaya /* all_water_perkaya */

	/* Tax collection */
	/* tot_tax_perkaya */ tot_tax_usd

	/* HH01 data on local contributions */
	/* hh_taxes hh_taxes_usd */
	/* hh_school hh_school_usd */
	hh_taxes_school_usd

	= elfr $control1) if kenya==0,
	small dfk corr;
test elfr;

/* NOW INCLUDE INEQUALITY, INCOME CONTROLS */;
sureg (/* ALL TZ OUTCOMES */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

/* TANZANIA ONLY DATA */
	/* Value of projects */
	/* yrexp_cm_tot_perkaya */ tot_funds_usd 
	/* yrexp_cm_well_perkaya well_funds_usd */
	/* yrexp_cm_health_perkaya health_funds_usd */
	health_well_funds_usd

	/* Number of projects */
	cm_num_peryr

	/* Road Quality */
	roads

	/* Wells */
	flow_water_perkaya /* all_water_perkaya */

	/* Tax collection */
	/* tot_tax_perkaya */ tot_tax_usd

	/* HH01 data on local contributions */
	/* hh_taxes hh_taxes_usd */
	/* hh_school hh_school_usd */
	hh_taxes_school_usd

	= elfr $control1 $control2) if kenya==0,
	small dfk corr;
test elfr;

sureg (/* ALL TZ OUTCOMES */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 
/* TANZANIA ONLY DATA */
	/* Value of projects */
	/* yrexp_cm_tot_perkaya */ tot_funds_usd 
	/* yrexp_cm_well_perkaya well_funds_usd */
	/* yrexp_cm_health_perkaya health_funds_usd */
	health_well_funds_usd

	/* Number of projects */
	cm_num_peryr

	/* Road Quality */
	roads

	/* Wells */
	flow_water_perkaya /* all_water_perkaya */

	/* Tax collection */
	/* tot_tax_perkaya */ tot_tax_usd

	/* HH01 data on local contributions */
	/* hh_taxes hh_taxes_usd */
	/* hh_school hh_school_usd */
	hh_taxes_school_usd

	= elfr $control1 $ex) if kenya==0,
	small dfk corr;
test elfr;

/* STACK ALL COMMON OUTCOMES INTO ONE REGRESSION */;
stack
	vid2 wardno $control1 $kx $divisions elfr kenya kenya_elfr yrexp_cm_sch_perpup_std
	vid2 wardno $control1 $kx $divisions elfr kenya kenya_elfr desks_perpup_std
	vid2 wardno $control1 $kx $divisions elfr kenya kenya_elfr latrin_perpup_std
	vid2 wardno $control1 $kx $divisions elfr kenya kenya_elfr classr_perpup_std
	vid2 wardno $control1 $kx $divisions elfr kenya kenya_elfr prop_water_std,
	into(vid2 wardno $control1 $kx $divisions elfr kenya kenya_elfr coll_act) clear;
tab _stack, gen(Istack);
drop _stack;
save f_stack, replace;

regress coll_act elfr kenya kenya_elfr, robust;
regress coll_act elfr kenya kenya_elfr, robust cluster(vid2);
regress coll_act elfr kenya kenya_elfr, robust cluster(wardno);
regress coll_act elfr kenya kenya_elfr $control1, robust cluster(vid2);
regress coll_act elfr kenya kenya_elfr $control1, robust cluster(wardno);
regress coll_act elfr kenya kenya_elfr $control1 $kx, robust cluster(wardno);

gen tz = 1-kenya;
gen tz_elfr = tz*elfr;
regress coll_act elfr tz tz_elfr $control1, robust cluster(wardno);


/* NON-PARAMETRIC graph7S OF NORMALIZED OUTCOMES */;
ksm coll_act elfr if kenya==1, lowess title(Collection Action in Kenya)
	saving(coll_K, replace) gen(coll_K) bw(0.5);
display r(width);

ksm coll_act elfr if kenya==0, lowess title(Collection Action in TZ) 
	saving(coll_TZ, replace) gen(coll_TZ) bw(0.5);
display r(width);

label var coll_K "Collective Action in Kenya";
label var coll_TZ "Collective Action in Tanzania";
sort elfr;
graph7 coll_K coll_TZ elfr, title(Collection Action in K and TZ) s(ii) c(ll[-])
	xlabel (0, 0.2, 0.4, 0.6) ylabel saving(coll_KTZ, replace);


clear;
/* EXAMINE ALL OUTCOMES, NOT JUST COMMON ONES - REFER TO TZ-ETHNIC_12AUG02.DO */;



/* COLLAPSE TO THE WARD LEVEL, FOR graph7S */;
use f_schools;

collapse 
 rfeduc rfwork latrine ironroo sibling
 totstud pup2tch tchIV yrstch tchsex hmtchIV hmyrssch
 water healthy yuca tobacco sugarcan cotton cashcrop
 sweetpot beans millet cassava maize banana livest goat owncows pig sheep
 catholic cpk
 educat myrsed formal_work mformwk
 funyula butula nambale matayos budalang amukura
 rethnic2 ethnic2
 rfformwk rlatrine rcashcrop rlivest sc98_press
 schage sch_5km bks2pup text2pup

 yrexp_cm_sch_perpup yrexp_cm_sch_perpup_std
 desks_perpup desks_perpup_std
 latrin_perpup latrin_perpup_std
 classr_perpup classr_perpup_std
 all_water all_water_std
 prop_water prop_water_std
 collact_std
 kenya
	[aw = totstud],
 	by (wardno);

summ rethnic2, det;
rename rethnic2 elfr_ward;

replace wardno = wardno + 100;
sort wardno;
 
save f_zone, replace;
clear;


/* NEED TO MERGE TOGETHER KENYA AND TANZANIA DATA AND GIVE VARIABLES COMMON NAMES */;
use f_ward;
append using f_zone;
tab wardno;

replace kenya = 0 if kenya==.;
summ kenya;
sort kenya;

/* FUNDRAISING PER PUPIL AND PER HOUSEHOLD, PER YEAR, IN 2002 USD */;
/*
The KSH:USD exchange rate in June 1995 was 53.2:1, according to:
http://www.oanda.com/convert/classic
*/;

/* 
The TZSH:USD exchange rate in June 2001 was 886:1, according to:
http://www.oanda.com/convert/classic
The TZSH:USD exchange rate in August 2002 was 984:1, according to:
http://www.oanda.com/convert/classic

The 2002 figure is the key rate for us, since the project price figures we
obtained from DRDP are for 2002.  The 2001 HH and VC data is converted
at the 2001 rate, above.
*/;

/* Inflation in the US between 1995 and 2002 was 1/0.845, and between 2001 and 2002 was 1/0.982
according the Census Bureau and the Bureau of Labor Statistics:
http://www.orst.edu/dept/pol_sci/fac/sahr/sahr.htm
*/;

gen sch_funds_usd = yrexp_cm_sch_perpup/53.2/0.845 if kenya==1;
/* For years 1997 to 2002 in Tanzania - divide by six years */;
replace sch_funds_usd = yrexp_cm_sch_perpup/984/6 if kenya==0;
gen tot_funds_usd = yrexp_cm_tot_perkaya/984/6 if kenya==0;
gen well_funds_usd = yrexp_cm_well_perkaya/984/6 if kenya==0;
gen health_funds_usd = yrexp_cm_health_perkaya/984/6 if kenya==0;

gen tot_tax_usd = tot_tax_perkaya/886/0.982 if kenya==0;
gen hh_taxes_usd = hh_taxes/886/0.982 if kenya==0;
gen hh_school_usd = hh_school/886/0.982 if kenya==0;

/* COMBINE SEVERAL OF THESE MEASURES */;
gen hh_taxes_school_usd = hh_taxes_usd + hh_school_usd;
gen health_well_funds_usd = well_funds_usd + health_funds_usd;


/* INCLUDE DIVISION/REGION DUMMIES FOR BOTH COUNTRIES */;
/* Which do these correspond to? */;
replace Idiv1 = 0 if Idiv1==.;
replace Idiv2 = 0 if Idiv2==.;

foreach var in
	funyula butula nambale matayos budalang amukura
	{;
	replace `var' = 0 if `var'==.;
	};

/* GENERATE KENYA*ELF INTERACTION TERM */;
gen kenya_elfr = kenya*elfr_ward;
sort kenya;
save f1, replace;


/* WARD LEVEL DIVERSITY ACROSS DISTRICTS */;
/* Kernel density of diversity */;
kdensity elfr_ward if kenya==1, title(Zonal Diversity Kenya)
	saving(elf_ward_K, replace) gen(xa elf_K);
display r(width);
kdensity elfr_ward if kenya==0, title(Ward Diversity Tanzania)
	saving(elf_ward_TZ, replace) gen(xb elf_TZ);
display r(width);

label var xa "ELF";
label var elf_K "Zone Diversity Kenya";
label var elf_TZ "Ward Diversity Tanzania";
graph7 elf_K elf_TZ xa, s(ii) c(ll[-])
	xlabel (0, 0.2, 0.4, 0.6) ylabel saving(elf_ward_KTZ, replace);
drop xa xb;


/* EXAMINE ETHNIC DIVERSITY EFFECTS */;
foreach var in
/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

/* TANZANIA ONLY DATA */
	/* Value of projects */
	/* yrexp_cm_tot_perkaya */ tot_funds_usd 
	/* yrexp_cm_well_perkaya well_funds_usd */
	/* yrexp_cm_health_perkaya health_funds_usd */
	health_well_funds_usd

	/* Number of projects */
	cm_num_peryr

	/* Road Quality */
	roads

	/* Wells */
	flow_water_perkaya all_water_perkaya

	/* Tax collection */
	/* tot_tax_perkaya */ tot_tax_usd

	/* HH01 data on local contributions */
	/* hh_taxes hh_taxes_usd */
	/* hh_school hh_school_usd */
	hh_taxes_school_usd

	/* Group outcomes */
	totgrp_perkaya femgrp_perkaya ythgrp_perkaya wtrgrp_perkaya /* VC01 */
	commgrp /* HH01 */

	/* Village meeting attendance */
	vmtg01_perkaya

	{;
	graph7 `var' elfr if kenya==1, xlabel saving(`var'_wK, replace);
	graph7 `var' elfr if kenya==0, xlabel saving(`var'_wTZ, replace);
	by kenya: regress `var' elfr_ward $control1, robust;
	by kenya: regress `var' elfr_ward $control1 y_vill gini_vill, robust;
	/* regress `var' kenya elfr_ward kenya_elfr, robust; */;
	regress `var' kenya elfr_ward kenya_elfr $control1, robust;
	};

/* TEST DIFFERENCE BETWEEN KENYA, TZ */;
sureg (/* COMMON OUTCOMES WITH KENYA */
	/* School Outcomes */
	sch_funds_usd
	desks_perpup
	latrin_perpup
	classr_perpup

	/* Wells */
	prop_water 

	= kenya elfr_ward kenya_elfr $control1),
	small dfk corr;
test elfr_ward;
test kenya_elfr;

/* Graph outcomes */;
/* FIGURES 2a, 2b: SCHOOL FUNDING OUTCOMES (USD) */;
regress sch_funds_usd elfr_ward if kenya==1;
gen k_funds = sch_funds_usd if kenya==1;
predict k_funds_hat;

regress sch_funds_usd elfr_ward if kenya==0;
gen tz_funds = sch_funds_usd if kenya==0;
predict tz_funds_hat;

label var elfr_ward "Local Ethnic diversity (ELF)";
label var k_funds "School Funding Kenya (USD)";
label var tz_funds "School Funding Tanzania (USD)";
graph7 k_funds tz_funds k_funds_hat tz_funds_hat elfr_ward,
	s(OTii) c(..ll[.]) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k-tz_school-figure_w, replace); 
graph7 k_funds k_funds_hat elfr_ward,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k_school-figure_w, replace); 
graph7 tz_funds tz_funds_hat elfr_ward,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(tz_school-figure_w, replace); 


/* POOLED OUTCOMES */;
regress collact_std elfr_ward if kenya==1;
gen k_pool = collact_std if kenya==1;
predict k_pool_hat;

regress collact_std elfr_ward if kenya==0;
gen tz_pool = collact_std if kenya==0;
predict tz_pool_hat;

label var elfr_ward "Local Ethnic diversity (ELF)";
label var k_pool "Normalized Pooled Collective Action, Kenya";
label var tz_pool "Normalized Pooled Collective Action, TZ";
graph7 k_pool tz_pool k_pool_hat tz_pool_hat elfr_ward,
	s(OTii) c(..ll[.]) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k-tz_pool-figure, replace); 
graph7 k_pool k_pool_hat elfr_ward,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k_pool-figure, replace); 
graph7 tz_pool tz_pool_hat elfr_ward,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(tz_pool-figure, replace); 


/* Graph desks per pupil outcomes */;
regress desks_perpup elfr_ward if kenya==1;
gen k_desks = desks_perpup if kenya==1;
predict k_desks_hat;

regress desks_perpup elfr_ward if kenya==0;
gen tz_desks = desks_perpup if kenya==0;
predict tz_desks_hat;

label var elfr_ward "Local Ethnic diversity (ELF)";
label var k_desks "Desks per pupil Kenya";
label var tz_desks "Desks per pupil Tanzania";
graph7 k_desks tz_desks k_desks_hat tz_desks_hat elfr_ward,
	s(OTii) c(..ll[.]) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k-tz_desks-figure, replace); 
graph7 k_desks k_desks_hat elfr_ward,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k_desks-figure, replace); 
graph7 tz_desks tz_desks_hat elfr_ward,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(tz_desks-figure, replace); 


/* DO NOT PRESENT IN PAPER */;
/* Graph prop. working wells outcomes */;
regress prop_water elfr_ward if kenya==1;
gen k_water = prop_water if kenya==1;
predict k_water_hat;

regress prop_water elfr_ward if kenya==0;
gen tz_water = prop_water if kenya==0;
predict tz_water_hat;

label var elfr_ward "Local Ethnic diversity (ELF)";
label var k_water "Prop. wells work, Kenya";
label var tz_water "Prop. wells work, Tanzania";
graph7 k_water tz_water k_water_hat tz_water_hat elfr_ward,
	s(OTii) c(..ll[.]) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k-tz_water-figure, replace); 
graph7 k_water k_water_hat elfr_ward,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(k_water-figure, replace); 
graph7 tz_water tz_water_hat elfr_ward,
	s(O.) c(.l) xlabel(0, 0.2, 0.4, 0.6) ylabel saving(tz_water-figure, replace); 
clear;


/* EXPLORING RESIDENTIAL STABILITY */;
use f0;
keep vid* elf*;
sort vid;
save f1, replace;
clear;

/* CHANGE TO SEPTEMBER HH DATA */;

use h_all21jun02;
rename villno vid;
sort vid;

merge vid using f1;
tab _merge; drop _merge;

sort gender;

/* What proportion of individuals were born in this village (=1), elsewhere in Meatu (=2),
	or in other districts (=3)? */
/* This is important for identification, the less mobility the better for identification */;

tab born;
by gender: tab born;
/* Restrict attention to younger males, since older males born before there were villages */;
/* Were hard-copy checks done on these? */;

/* For diverse and non-diverse areas, too */;

gen age_2 = age;
replace age_2 = 2001-yrborn if (age==. | age<16 | age>91);
replace age_2 = . if (age_2<16 | age_2>91);
summ age yrborn age_2;
by gender: tab born if age_2<50;
by gender: tab born if age_2<30;
by gender: tab born if age_2<25;

by gender: tab born if age_2<50 & elfr>0.15;
by gender: tab born if age_2<30 & elfr>0.15;
by gender: tab born if age_2<25 & elfr>0.15;

by gender: tab born if age_2<50 & elfr<=0.15;
by gender: tab born if age_2<30 & elfr<=0.15;
by gender: tab born if age_2<25 & elfr<=0.15;

/* In which year did they move into the village, given that they were not born there? */;
tab moveyr if (born~=1 & born~=. & moveyr~=9999);
/* Among male respondents, who do not typically move upon marriage */;
by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999);
by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999) & age_2<30;
by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999) & age_2<25;

by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999) & elfr>0.15;
by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999) & age_2<30 & elfr>0.15;
by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999) & age_2<25 & elfr>0.15;

by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999) & elfr<=0.15;
by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999) & age_2<30 & elfr<=0.15;
by gender: tab moveyr if (born~=1 & born~=. & moveyr~=9999) & age_2<25 & elfr<=0.15;

/* SEPARATE DO-FILE ON WITCH-KILLINGS - refer to tz-ethnic_17jul02.do */;
log c;

